@@ -1,6 +1,10 @@
 # Licensed under the MIT License
 # https://github.com/craigahobbs/markdown-up-py/blob/main/LICENSE
 
+"""
+markdown-up top-level script environment
+"""
+
 from .main import main
 
 
